package ch.ethz.inf.vs.android.nethz.tutorial;

import android.hardware.Camera;
import android.media.MediaPlayer;
import android.os.Bundle;
import android.os.Vibrator;
import android.app.Activity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.SeekBar;
import android.widget.Toast;
import android.widget.ToggleButton;

public class ActuatorsActivity extends Activity {
	
	private MediaPlayer mp = null;
	private Camera cam = null;
	private Vibrator vib = null;
	private int duration = 50;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_actuators);
		// Show the Up button in the action bar.
		setupActionBar();
		
		initPlayer(false);
		
		vib = (Vibrator) getSystemService(VIBRATOR_SERVICE);

		SeekBar seekDuration = (SeekBar) findViewById(R.id.seek_duration);
		seekDuration.setOnSeekBarChangeListener( new 	SeekBar.OnSeekBarChangeListener() {
				public void onProgressChanged(SeekBar seekBar,
									   int progress,
									   boolean fromUser) {
					duration = progress;
				}
				public void onStartTrackingTouch(SeekBar seekBar) {}
				public void onStopTrackingTouch(SeekBar seekBar) {
					vib.vibrate(duration*10);
				}
			});
	}
	
	@Override
	public void onPause() {
		super.onPause();
		
		if (cam!=null) {
			cam.release();
			cam = null;
			Toast.makeText(this, "Camera released", Toast.LENGTH_LONG).show();
		}
	}

	@Override
	public void onResume() {
		super.onResume();
		
		((ToggleButton)findViewById(R.id.btn_flash)).setChecked(false);
	}

	private void initPlayer(boolean loop) {
		mp = MediaPlayer.create(this, loop ? R.raw.loop : R.raw.sound); 
		mp.setVolume(1.0f, 1.0f);
		mp.setLooping(loop);
	}

	
	public void onClickVibrate(View v) {
		long[] pattern = { 0, 100, 100, 200, 100, 100 };
		vib.vibrate(pattern, -1);
	}
	
	public void onClickSound(View v) {
//		MediaPlayer mp = MediaPlayer.create(this, R.raw.sound);
//		mp.setVolume(1.0f, 1.0f);
//		mp.start();

		if (!mp.isPlaying()) {
			mp.start();
			if (mp.isLooping()) {
				((Button)v).setText(R.string.btn_running);
			}
		} else {
			mp.stop();
			try {
				mp.prepareAsync();
			} catch (IllegalStateException e) {
				// This is a demo. See Android policy on try/catch!
			}
			((Button)v).setText(R.string.btn_sound);
		}
	}
	
	public void onClickFlash(View v) {
		ToggleButton tb = (ToggleButton) v;
		if (tb.isChecked()) {
			cam = Camera.open();
			Camera.Parameters parameters = cam.getParameters();
			parameters.setFlashMode(Camera.Parameters.FLASH_MODE_TORCH);
			cam.setParameters(parameters);
		} else {
			cam.release();
			cam = null;
		}
	}

	/**
	 * Set up the {@link android.app.ActionBar}.
	 */
	private void setupActionBar() {

		getActionBar().setDisplayHomeAsUpEnabled(true);

	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.actuators, menu);

		super.onPrepareOptionsMenu(menu);
		if (mp.isPlaying()) return false;
		else return true; 
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case R.id.menu_looping:
			initPlayer(true);
			return true;
		case R.id.menu_once: 
			initPlayer(false);
			return true;
		case R.id.menu_back:
			finish();
			return true;
		default:
			return super.onOptionsItemSelected(item);
		}
	}
}
